@@ -21,7 +21,7 @@ Introduced in version 0.08, published on February 7, 2005.
 
 =head1 SEE ALSO
 
-L<Acme::MetaSyntactic>
+L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
 =cut
 
